@@ -55,20 +55,18 @@ class cli:
             self.instaled = i.validate_installation()
 
             if not self.instaled:
-                i.create_crontab_files()
-                i.set_instaled_true()
-                i.fill_default_task_file()
+                i.full_install()
             
 
         # TODO: Ajust this part to read a boolean, not string
+        # TODO: Correct the read of task_example and reativate generate_yaml
+
         if self.instaled == 'false' or self.instaled == 'False':
             main_cli.add_command(install)
         else:
             main_cli.add_command(now)
             main_cli.add_command(schedule)
             main_cli.add_command(rsync)
-            main_cli.add_command(generate_yaml)
-        
-                
+            #main_cli.add_command(generate_yaml)
         
         main_cli()
